---
title: <span class="badge object-type-enum"></span> CodeLanguage
---
# <span class="badge object-type-enum"></span> CodeLanguage

## Definition

```python
class CodeLanguage(enum.StrEnum):
    JSON = "json"
    YAML = "yaml"
    XML = "xml"
    TYPESCRIPT = "typescript"
    SQL = "sql"
    GO = "go"
    MARKDOWN = "markdown"
    HTML = "html"
    PLAINTEXT = "plaintext"
```
